summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--package.scm4
1 files changed, 2 insertions, 2 deletions
diff --git a/package.scm b/package.scm
index 18097e8..a5343f9 100644
--- a/package.scm
+++ b/package.scm
@@ -33,13 +33,13 @@
(gnu packages maths)
(gnu packages image))
;; The development environment needs a tweaked LD_LIBRARY_PATH for
;; finding libfreeimage.
(define freeimage
(package (inherit freeimage)
(native-search-paths
(list (search-path-specification
- (variable "LD_LIBRARY_PATH")
+ (variable "LTDL_LIBRARY_PATH")
(directories '("lib")))))))
(package
@@ -33,13 +33,13 @@
(gnu packages maths)
(gnu packages image))
-;; The development environment needs a tweaked LD_LIBRARY_PATH for
+;; The development environment needs a tweaked LTDL_LIBRARY_PATH for
;; finding libfreeimage.
(define freeimage